netapp_ontap.models.volume_nas_junction_parent API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.models.volume_nas_junction_parent`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Classes

`class VolumeNasJunctionParentSchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the VolumeNasJunctionParent object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `links: SelfLink GET`

    The links field of the volume_nas_junction_parent.

  `name: str GET POST PATCH`

    The name of the parent volume that contains the junction inode of this volume. The junction parent volume must belong to the same SVM that owns this volume.

    Example: vs1_root

  `uuid: str GET POST PATCH`

    Unique identifier for the parent volume.

    Example: 75c9cfb0-3eb4-11eb-9fb4-005056bb088a